<?php

// register shortcode to display signatures list
add_shortcode( 'signaturelist', 'dk_speakup_signatures_shortcode' );
function dk_speakup_signatures_shortcode( $attr ) {

	// only query a petition if the id attribute has been set
	if ( isset( $attr['id'] ) && is_numeric( $attr['id'] ) ) {

		include_once( 'class.signature.php' );
		$the_signatures = new dk_speakup_Signature();
		$options = get_option( 'dk_speakup_options' );
		$id = $attr['id'];

		// get the signatures for display
		$columns = unserialize( $options['signaturelist_columns'] );

		$signatures = $the_signatures->all_cached( $id, 'signaturelist' );

		$signatures_count = $the_signatures->count_cached( $id, 'signaturelist' );
		$current_signature_number = $signatures_count;

		// only show signature lists if there are signatures
		$signatures_list = '';
		if ( $signatures_count > 0 ) {
			// determine which columns to display
			$display_city     = ( in_array( 'sig_city', $columns ) ) ? 1 : 0;
			$display_state    = ( in_array( 'sig_state', $columns ) ) ? 1 : 0;
			$display_postcode = ( in_array( 'sig_postcode', $columns ) ) ? 1 : 0;
			$display_country  = ( in_array( 'sig_country', $columns ) ) ? 1 : 0;
			$display_custom   = ( in_array( 'sig_custom', $columns ) ) ? 1 : 0;
			$display_date     = ( in_array( 'sig_date', $columns ) ) ? 1 : 0;

			// write the HTML
			$signatures_list = '
				<h3 class="dk-speakup-signaturelist_header">' . $options['signaturelist_header'] . '</h3>
					<table class="dk-speakup-signaturelist">
			';

			$row_count = 0;
			foreach ( $signatures as $signature ) {
				if ( $row_count % 2 ) {
					$signatures_list .= '<tr class="dk-speakup-even">';
				}
				else {
					$signatures_list .= '<tr class="dk-speakup-odd">';
				}
				$signatures_list .= '<td class="dk-speakup-signaturelist-count">' . number_format( $current_signature_number, 0, '.', ',' ) . '</td>';
				$signatures_list .= '<td class="dk-speakup-signaturelist-name">' . stripslashes( $signature->first_name . ' ' . $signature->last_name ) . '</td>';

				// if we display both city and state, combine them into one column
				$city  = ( $display_city )  ? $signature->city : '';
				$state = ( $display_state ) ? $signature->state : '';
				if ( $display_city && $display_state ) {
					// should we separate with a comma?
					$delimiter = ( $city !='' && $state != '' ) ? ', ' : '';
					$signatures_list .= '<td class="dk-speakup-signaturelist-city">' . stripslashes( $city . $delimiter . $state ) . '</td>';
				}
				// else keep city or state values in their own column
				else {
					if ( $display_city ) $signatures_list  .= '<td class="dk-speakup-signaturelist-city">' . stripslashes( $city ) . '</td>';
					if ( $display_state ) $signatures_list .= '<td class="dk-speakup-signaturelist-state">' . stripslashes( $state ) . '</td>';
				}

				if ( $display_postcode ) $signatures_list .= '<td class="dk-speakup-signaturelist-postcode">' . stripslashes( $signature->postcode ) . '</td>';
				if ( $display_country ) $signatures_list  .= '<td class="dk-speakup-signaturelist-country">' . stripslashes( $signature->country ) . '</td>';
				if ( $display_custom ) $signatures_list   .= '<td class="dk-speakup-signaturelist-custom">' . stripslashes( $signature->custom_field ) . '</td>';
				if ( $display_date ) $signatures_list     .= '<td class="dk-speakup-signaturelist-date">' . ucfirst ( date_i18n( 'M d, Y', strtotime( $signature->date ) ) ) . '</td>';
				$signatures_list .= '</tr>';
 
				$current_signature_number --;
				$row_count ++;
			}
			$signatures_list .= '</table>';
		}

		return $signatures_list;
	}
}

// load CSS on pages/posts that contain the [signaturelist] shortcode
add_filter( 'the_posts', 'dk_speakup_signaturelist_css' );
function dk_speakup_signaturelist_css( $posts ) {

	// ignore if there are no posts
	if ( empty( $posts ) ) return $posts;

	$options = get_option( 'dk_speakup_options' );

	// set flag to determine if post contains shortcode
	$shortcode_found = false;

	foreach ( $posts as $post ) {
		// if post content contains the shortcode
		if ( strstr( $post->post_content, '[signaturelist' ) ) {
			// update flag
			$shortcode_found = true;
			break;
		}
	}

	// if flag is now true, load the CSS
	if ( $shortcode_found ) {
		$theme = $options['signaturelist_theme'];

		 // load default theme
		if ( $theme === 'default' ) {
			wp_enqueue_style( 'dk_speakup_signaturelist_css', plugins_url( 'speakup-email-petitions/css/signaturelist.css' ) );
		}
		// attempt to load cusom theme (petition-signaturelist.css)
		else {
			$parent_dir       = get_template_directory_uri();
			$parent_theme_url = $parent_dir . '/petition-signaturelist.css';

			// if a child theme is in use
			// try to load style from child theme folder
			if ( is_child_theme() ) {
				$child_dir        = get_stylesheet_directory_uri();
				$child_theme_url  = $child_dir . '/petition-signaturelist.css';
				$child_theme_path = STYLESHEETPATH . '/petition-signaturelist.css';

				// use child theme if it exists
				if ( file_exists( $child_theme_path ) ) {
					wp_enqueue_style( 'dk_speakup_signaturelist_css', $child_theme_url );
				}
				// else try to load style from parent theme folder
				else {
					wp_enqueue_style( 'dk_speakup_signaturelist_css', $parent_theme_url );
				}
			}
			// if not using a child theme, just try to load style from active theme folder
			else {
				wp_enqueue_style( 'dk_speakup_signaturelist_css', $parent_theme_url );
			}
		}
	}

	return $posts;
}

?>